/*
    *
    * This file is a part of CoreTime.
    * A time related task manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#ifndef ALARM_H
#define ALARM_H

#include <QWidget>

#include "alarmschedulequeue.h"


class AlarmItem;

namespace Ui {
    class Alarm;
}

class Alarm : public QWidget {
    Q_OBJECT

public:
    explicit Alarm(QWidget *parent = nullptr);
    ~Alarm();

protected:
    bool event(QEvent *event);

private slots:
    void on_m_weekdays_toggled(bool arg1);
    void on_m_browse_clicked();
    void on_m_ok_clicked();
    void on_m_cancel_clicked();
    void on_m_alarmList_itemSelectionChanged();

    void on_chkReminderText_toggled(bool checked);

private:
    Ui::Alarm          *ui;
    AlarmScheduleQueue  m_alarmQueue;
    AlarmItem          *temp;

    bool m_addAlarm;
    bool m_editAlarm;

    void changeState(bool change);
    void configToAlarmItem(AlarmItem *item);
    void loadAlarmItems();
    void saveAlarmItems();
    void alarmItemToggled(bool enable);

    ///////////////////// Config /////////////////////////
    void initializeConfig();
    bool checkConfig();
    //////////////////////////////////////////////////////

    void addAlarm();
    void editAlarm();
    void removeAlarm();
};

#endif // ALARM_H
