/*
    *
    * This file is a part of CoreTime.
    * A time related task manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#ifndef ALARMITEM_H
#define ALARMITEM_H

#include <QWidget>
#include <QMap>
#include <QTime>


class QCheckBox;
class QLabel;

class AlarmItem : public QWidget {
    Q_OBJECT

public:
    explicit AlarmItem(QWidget *parent = nullptr);
    ~AlarmItem();

    enum AlarmType {
        Once = 0,
        Repeat,
        Snoozed
    };

    enum WeekDay {
        Monday = 0,
        Tuesday,
        Wednesday,
        Thursday,
        Friday,
        Saturday,
        Sunday
    };

    QTime getStartTime() const;
    void setStartTime(const QTime &startTime);
    bool getIsAlarmEnable() const;
    void setAlarmEnable(bool enable);
    QString getReminderText() const;
    void setReminderText(const QString &name);
    QTime getSnoozeTime() const;
    void setSnoozeTime(const QTime &snoozeTime);
    AlarmType getAlarmType() const;
    void setAlarmType(const AlarmType &t);
    bool getIsRepeat() const;
    void setRepeat(bool repeat);
    bool getIsWeekdayEnable(WeekDay w) const;
    void setWeekdayEnable(WeekDay w, bool enable);
    bool getIsCustomSound() const;
    void setIsCustomSound(bool enable);
    QString getCustomSoundFile() const;
    void setCustomSoundFile(const QString &file);
    void loadAlarm(int index);
    void saveAlarm(int index);
    void deleteAlarm(int index);
    QString weekdayToString() const;
    static WeekDay intToWeekday(int w);

signals:
    void alarmEnableToggled(bool checked);

public:
    QCheckBox *m_alarmCheck;
    QString    m_reminderText;
    QLabel    *m_startTimeLabel;
    QTime      m_startTime;
    QLabel    *m_alarmWeekday;
    QTime      m_snoozeTime;
    QString    m_customSoundFile;
    bool       m_repeat;
    bool       m_isCustomSound;
    AlarmType  m_alarmType;

    QMap<WeekDay, bool> m_weekdays;

};

#endif // ALARMITEM_H
