/*
    *
    * This file is a part of CoreTime.
    * A time related task manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#ifndef ALARMSCHEDULEQUEUE_H
#define ALARMSCHEDULEQUEUE_H

#include <QObject>
#include <QMap>
#include <QTimer>


class AlarmItem;

class AlarmScheduleQueue : public QObject {
    Q_OBJECT

public:
    explicit AlarmScheduleQueue(QObject *parent = nullptr);
    ~AlarmScheduleQueue();

    void add(const AlarmItem *a);
    void remove(const AlarmItem *a);
    void modify(const AlarmItem *a);

private:
    QTimer m_timer;
    QMap<const AlarmItem *, QDateTime> m_alarmMap;

    QDateTime findNextAlarm(const AlarmItem *a, const QDateTime &dt, bool inclusive = false);
    void alarm(const AlarmItem *a, const QDateTime &dt);
    bool extractAudio();
    bool delExtracted();

public slots:
    void timerTimeout();

};

#endif // ALARMSCHEDULEQUEUE_H
