/*
    *
    * This file is a part of CoreTime.
    * A time related task manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#ifndef CORETIME_H
#define CORETIME_H

#include <QWidget>
#include <QToolButton>

#include <cprime/settingsmanage.h>


class QPushButton;
class QTimer;
class StopWatch;

namespace Ui {
    class coretime;
}

class coretime : public QWidget {

    Q_OBJECT

public:
    explicit coretime(QWidget *parent = nullptr);
    ~coretime();

protected:
    void closeEvent(QCloseEvent *event);

private slots:
    void updateTimer();
    void on_startandpause_clicked(bool checked);
    void on_lapandreset_clicked();
    void on_addTimer_clicked();
    void on_startstopTimer_clicked(bool checked);
    void on_resetTimer_clicked();
    void pageClick(QToolButton *btn, int i, QString title);
    void on_alarm_clicked();
    void on_stopwatch_clicked();
    void on_timer_clicked();
    void on_clock_clicked();
    void on_appTitle_clicked();

private:
    Ui::coretime   *ui;
    settingsManage *sm = settingsManage::initialize();
    QTimer         *clockTimer;
    StopWatch      *st;
    qint64          mSessionTime;
    bool            sideView, touch;
    int             sideViewSize;
    QSize           sideViewIconSize;
    QTimer         *forTimer;

    void startSetup();
    void loadSettings();
    void initializeClock();
    void initializeAlarm();
    void initializeStopwatch();
    void initializeTimer();
    void updateStopwatchTime(int time);

    static constexpr int MSECS_PER_HOUR = 3600000;
    static constexpr int MSECS_PER_MIN = 60000;
    static constexpr int MSECS_PER_SEC = 1000;
    static constexpr int SECS_PER_MIN = 60;
};

#endif // CORETIME_H
